package com.autentia.tutoriales.spring.daojdbc.managers;

import java.util.List;
import org.springframework.jdbc.core.RowMapper;
import org.springframework.orm.hibernate3.HibernateTemplate;
import com.autentia.tutoriales.spring.daojdbc.entity.Product;

/**
 * Ejemplo del uso de la platilla de Hibernate
 * Observe que no hay establecimientos/liberacion de recursos y tampoco gestión de excepciones....
 * 
 * 	Nota: Suponemos que la tabla existe:
 * 		  create table if not exists productos (codigo varchar(32) primary key, descripcion varchar(255))
 * 
 * @author Carlos García. Autentia.
 * @see http://www.mobiletest.es
 */
public class HibernateProductoDao  {
	private HibernateTemplate template;
	
	/**
	 * Plantilla inyectada por Spring
	 */
	public void setTemplate(HibernateTemplate template) {
		this.template = template;
	}

	/**
	 * Recupera un producto por su código
	 * @param codigo Código del producto a recuperar
	 * @return El producto buscado
	 */
	public Product get(String codigo){
		Product			  producto  = (Product) template.load(Product.class, codigo); 
		return producto;
	}
	
	/**
	 * Eliminar un producto
	 */
	public void delete(Product p){
		template.delete(p);
	}
	
	/**
	 * Añade un nuevo producto
	 */
	public void insert(Product p){
		template.saveOrUpdate(p);
	}
	
	/**
	 * Devuelve todos los productos
	 */
	public List<Product> getAll(){
		java.util.List<Product> productos	 = null;
		
		productos = template.find("from productos", new RowMapper(){
			public Product mapRow(java.sql.ResultSet rs, int rowNum) throws java.sql.SQLException {
				Product p = new Product();
				p.setCodigo(rs.getString(1));
				p.setDescripcion(rs.getString(2));
				return p;
			}
		}); 
		
		return productos;
	}
}
