package com.autentia.tutoriales.spring.daojdbc.managers;


import java.util.List;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.RowMapper;
import org.springframework.jdbc.core.support.JdbcDaoSupport;
import com.autentia.tutoriales.spring.daojdbc.entity.Product;

/**
 * Ejemplo del uso de plantilla JDBC.
 * Observe que no hay establecimientos/liberacion de recursos y tampoco gestión de excepciones....
 * 
 * 	Nota: Suponemos que la tabla existe:
 * 		  create table if not exists productos (codigo varchar(32) primary key, descripcion varchar(255))
 * 
 * @author Carlos García. Autentia.
 * @see http://www.mobiletest.es
 */
public class JdbcProductoDao {
	
	private JdbcTemplate jdbcTemplate;
	
	/**
	 * Plantilla injectada por Spring
	 */
	public void setJdbcTemplate(JdbcTemplate jdbcTemplate) {
		this.jdbcTemplate = jdbcTemplate;
		
	}

	/**
	 * Recupera un producto por su código
	 * @param codigo Código del producto a recuperar
	 * @return El producto buscado
	 */
	public Product get(String codigo){
		String[]	 params 	  = new String[]{codigo};
		Product		 prod		  = null;
		
		jdbcTemplate.setMaxRows(1);
		
		prod = (Product) jdbcTemplate.queryForObject("select codigo, descripcion from productos where codigo=?", params, new RowMapper(){
			public Object mapRow(java.sql.ResultSet rs, int rowNum) throws java.sql.SQLException {
				Product p = new Product();
				p.setCodigo(rs.getString(1));
				p.setDescripcion(rs.getString(2));
				return p;
			}
		}); 
		
		return prod;
	}
	
	/**
	 * Eliminar un producto
	 */
	public void delete(Product p){
		String[]	 params 	  = new String[]{p.getCodigo()};
		
		jdbcTemplate.update("delete from productos where codigo=?", params);
	}
	
	/**
	 * Añade un nuevo producto
	 * Se supone que el producto no existe.
	 */
	public void insert(Product p){
		String[]	 params 	  = new String[]{p.getCodigo(), p.getDescripcion()};
		jdbcTemplate.update("insert into productos (codigo, descripcion) values (?, ?)", params);
	}
	
	/**
	 * Devuelve todos los productos
	 */
	public List<Product> getAll(){
		List<Product> productos	 = null;
		
		productos = jdbcTemplate.query("select codigo, descripcion FROM productos", new RowMapper(){
			public Product mapRow(java.sql.ResultSet rs, int rowNum) throws java.sql.SQLException {
				Product p = new Product();
				p.setCodigo(rs.getString(1));
				p.setDescripcion(rs.getString(2));
				return p;
			}
		}); 
		
		return productos;
	}
}
